/*
 * Soya 3D
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "GL/gl.h"
#include "GL/glext.h"

#ifdef __WIN32__

#define GL_TEXTURE_BINDING_3D           0x806A
#define GL_POST_COLOR_MATRIX_ALPHA_BIAS 0x80BB

PFNGLMULTITEXCOORD2FARBPROC  glMultiTexCoord2f ;
PFNGLMULTITEXCOORD2FVARBPROC glMultiTexCoord2fv;
PFNGLACTIVETEXTUREARBPROC    glActiveTexture   ;

#endif

void init_advanced_opengl(void);


#ifndef GLAPIENTRY
#define GLAPIENTRY
#endif


// You may need to uncomment this if you use an old MacOS X
/*
typedef void (GLAPIENTRY *_GLUfuncptr)();
*/

